@@ -5,8 +5,10 @@ function _aws_cdk_aws_healthlake_CfnFHIRDatastoreProps(p) {
     try {
         if (!visitedObjects.has(p.preloadDataConfig))
             _aws_cdk_aws_healthlake_CfnFHIRDatastore_PreloadDataConfigProperty(p.preloadDataConfig);
-        if (!visitedObjects.has(p.tags))
-            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+        if (p.tags != null)
+            for (const o of p.tags)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
     }
     finally {
         visitedObjects.delete(p);
